"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGraphQLStringTypeByPath = void 0;
const graphql_1 = require("graphql");
/**
 * Getting a type of nested field inside graphQL schema using a path to this field
 *
 * @param schema - graphQL schema
 * @param currentField - field of graphQL schema
 * @param currentPath - path to nested field
 *
 * @returns - string type of nested field got by path
 */
function getGraphQLStringTypeByPath(schema, currentField, currentPath) {
    if (currentPath.length === 0) {
        return currentField.type.inspect();
    }
    const [head, ...tail] = currentPath;
    const { type } = currentField;
    const currentGraphQLType = type instanceof graphql_1.GraphQLList || type instanceof graphql_1.GraphQLNonNull
        ? schema.getType(type.ofType)
        : schema.getType(type.name);
    if (!(currentGraphQLType instanceof graphql_1.GraphQLObjectType)) {
        throw new Error(`${type.inspect()} isn't GraphQLObjectType for getting GraphQL String Type by path`);
    }
    const headField = currentGraphQLType.getFields()[head];
    if (headField === undefined) {
        throw new Error("Path doesn't exist");
    }
    return getGraphQLStringTypeByPath(schema, headField, tail);
}
exports.getGraphQLStringTypeByPath = getGraphQLStringTypeByPath;
//# sourceMappingURL=getGraphQLStringTypeByPath.js.map